==> fr.ac6.linux.utils_1.0.0.202202211611.jar: resources/scripts/partitioning/gpt_utils.sh <==
######################################################################################################################
#                                                                                                                    #
#                                          GUID Partition table utilities                                            #
#                                                                                                                    #
######################################################################################################################

##################################################
# Add GPT partition definition into sfdisk dump file
# 	dumpFile	sfdisk dump file to define disk image
# 	partName	Partition name
# 	partType	Partition type (binary, system, filesystem, shadow)
# 	partStart	Start sector
# 	partSize	Partition size in sectors count	
# 	extraOpts	Extra options		
##################################################
gpt_sfdisk_add_partition() {
	local dumpFile="${1}"
	local partName="${2}"
	local partType="${3}"
	local partStart="${4}"
	local partSize="${5}"
	local extraOpts="${6}"
	
	case ${partType} in
		binary)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=8DA63339-0007-60C0-C436-083AC8230908, name=\"${partName}\"${extraOpts}" >> ${dumpFile}
			;;
		system)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=BC13C2FF-59E6-4262-A352-B275FD6F7172, name=\"${partName}\"${extraOpts}" >> ${dumpFile}
			;;
		filesystem)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=0FC63DAF-8483-4772-8E79-3D69D8477DE4, name=\"${partName}\"${extraOpts}" >> ${dumpFile}
			;;
		shadow)
			# Shadow Partition that are not in the partition table
			;;
		*)
			fatal 1 "GPT Partition ${partName}: Type ${partType} is not supported"
			;;
	esac
}

==> fr.ac6.linux.utils_1.0.0.202304061034.jar: resources/scripts/partitioning/gpt_utils.sh <==
######################################################################################################################
#                                                                                                                    #
#                                          GUID Partition table utilities                                            #
#                                                                                                                    #
######################################################################################################################

##################################################
# Add GPT partition definition into sfdisk dump file
# 	dumpFile	sfdisk dump file to define disk image
# 	partName	Partition name
# 	partType	Partition type (binary, system, filesystem, shadow)
# 	partStart	Start sector
# 	partSize	Partition size in sectors count	
# 	extraOpts	Extra options		
##################################################
gpt_sfdisk_add_partition() {
	local dumpFile="${1}"
	local partName="${2}"
	local partType="${3}"
	local partStart="${4}"
	local partSize="${5}"
	local extraOpts="${6}"
	
	case ${partType} in
		binary)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=8DA63339-0007-60C0-C436-083AC8230908, name=\"${partName}\", ${extraOpts}" >> ${dumpFile}
			;;
		system)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=BC13C2FF-59E6-4262-A352-B275FD6F7172, name=\"${partName}\", ${extraOpts}" >> ${dumpFile}
			;;
		filesystem)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=0FC63DAF-8483-4772-8E79-3D69D8477DE4, name=\"${partName}\", ${extraOpts}" >> ${dumpFile}
			;;
		fip)
			echo -e "start=\t${partStart}, size=\t${partSize}, type=19D5DF83-11B0-457b-BE2C-7559C13142A5, name=\"${partName}\", ${extraOpts}" >> ${dumpFile}
			;;
		shadow)
			# Shadow Partition that are not in the partition table
			;;
		*)
			fatal 1 "GPT Partition ${partName}: Type ${partType} is not supported"
			;;
	esac
}
